from __future__ import division, unicode_literals, print_function  # for compatibility with Python 2 and 3

import matplotlib as mpl
import matplotlib.pyplot as plt
import numpy as np

import scipy.stats
import os
from matplotlib.ticker import AutoMinorLocator,Locator
from matplotlib import cm
from matplotlib.colors import ListedColormap, LinearSegmentedColormap

figure,ax=plt.subplots(nrows=1,ncols=1,figsize = (3.6,3))
plt.subplots_adjust(left= 0.18,wspace=0.38, hspace=0.38,top=0.98,bottom = 0.19, right = 0.98)

ax.tick_params(axis='y',**{'which':'major','width':2.2,'length':4,'direction':'in','left':True,'right':True})
ax.tick_params(axis='y',**{'which':'minor','width':1.5,'length':2.6,'direction':'in','left':True,'right':True})	
ax.tick_params(axis='x',**{'which':'major','width':1.9,'length':4,'direction':'in','bottom':True,'top':True})	
ax.tick_params(axis='x',**{'which':'minor','width':1.3,'length':2.2,'direction':'in','bottom':True,'top':True})
[line.set_linewidth(1.0) for line in ax.spines.values()]

analysisresults = np.loadtxt("processed_FRETData_Nlatch_variations.csv",delimiter=",",skiprows=1)
nlatch = analysisresults[1:,0]
FRET1 = analysisresults[1:,1]
FRET2 = analysisresults[1:,2]
sim_weak = analysisresults[1:,3]
sim_strong = analysisresults[1:,4]

ax.scatter(nlatch,FRET1,marker='^',c = "dimgrey",s=40)
ax.scatter(nlatch,FRET2,marker='^',c = "dimgrey",s=40)
ax.scatter(nlatch,sim_weak,c = "steelblue",s=30)
ax.scatter(nlatch,sim_strong,c = "firebrick",s=30)

plt.yticks([0,0.05,0.10,0.15])
plt.xticks([2,3,4,5,6,7])
ax.yaxis.set_minor_locator(AutoMinorLocator(4))
#ax.xaxis.set_minor_locator(AutoMinorLocator(2))

ax.set_xlabel(r'$N_{Latch}\ \mathrm{[nt]}$',fontsize=15)
ax.set_ylabel(r'$E\ \mathrm{[-]}$',fontsize = 15,rotation="vertical")

ax.set_xlim(left=1.3,right = 7.5)
ax.set_ylim(bottom = 0, top = 0.18)

for tick in ax.xaxis.get_major_ticks():
 	tick.label.set_fontsize(13) 

for tick in ax.yaxis.get_major_ticks():
 	tick.label.set_fontsize(13) 

plt.savefig("Ext.Fig1b.svg")
plt.show()
plt.close()
